#[non_exhaustive]pub enum CheckTriggerKind {
PullRequest {
number: u64,
},
MergeGroup,
Rerequested {
number: u64,
},
}Expand description
Why a check is due.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PullRequest
A pull request was opened, pushed to, reopened, or had its base branch changed.
MergeGroup
A merge queue asked for checks on a merge group.
Rerequested
Someone asked for the check again (check_run / check_suite
rerequested) on a pull request.